==> elasticbeanstalk-0.10.0-sources.jar: software/amazon/awscdk/services/elasticbeanstalk/cloudformation/ApplicationResourceProps.java <==
package software.amazon.awscdk.services.elasticbeanstalk.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:42:27.750Z")
public interface ApplicationResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::ElasticBeanstalk::Application.ApplicationName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
     */
    java.lang.Object getApplicationName();
    /**
     * ``AWS::ElasticBeanstalk::Application.ApplicationName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
     */
    void setApplicationName(final java.lang.String value);
    /**
     * ``AWS::ElasticBeanstalk::Application.ApplicationName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
     */
    void setApplicationName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::ElasticBeanstalk::Application.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::ElasticBeanstalk::Application.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::ElasticBeanstalk::Application.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
     */
    void setDescription(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
     */
    java.lang.Object getResourceLifecycleConfig();
    /**
     * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
     */
    void setResourceLifecycleConfig(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
     */
    void setResourceLifecycleConfig(final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value);

    /**
     * @return a {@link Builder} of {@link ApplicationResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ApplicationResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _applicationName;
        @javax.annotation.Nullable
        private java.lang.Object _description;
        @javax.annotation.Nullable
        private java.lang.Object _resourceLifecycleConfig;

        /**
         * Sets the value of ApplicationName
         * @param value ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @return {@code this}
         */
        public Builder withApplicationName(@javax.annotation.Nullable final java.lang.String value) {
            this._applicationName = value;
            return this;
        }
        /**
         * Sets the value of ApplicationName
         * @param value ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @return {@code this}
         */
        public Builder withApplicationName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._applicationName = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::ElasticBeanstalk::Application.Description``
         * @return {@code this}
         */
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::ElasticBeanstalk::Application.Description``
         * @return {@code this}
         */
        public Builder withDescription(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of ResourceLifecycleConfig
         * @param value ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @return {@code this}
         */
        public Builder withResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._resourceLifecycleConfig = value;
            return this;
        }
        /**
         * Sets the value of ResourceLifecycleConfig
         * @param value ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @return {@code this}
         */
        public Builder withResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value) {
            this._resourceLifecycleConfig = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApplicationResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ApplicationResourceProps build() {
            return new ApplicationResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $applicationName = _applicationName;
                @javax.annotation.Nullable
                private java.lang.Object $description = _description;
                @javax.annotation.Nullable
                private java.lang.Object $resourceLifecycleConfig = _resourceLifecycleConfig;

                @Override
                public java.lang.Object getApplicationName() {
                    return this.$applicationName;
                }

                @Override
                public void setApplicationName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$applicationName = value;
                }

                @Override
                public void setApplicationName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$applicationName = value;
                }

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(@javax.annotation.Nullable final java.lang.String value) {
                    this.$description = value;
                }

                @Override
                public void setDescription(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$description = value;
                }

                @Override
                public java.lang.Object getResourceLifecycleConfig() {
                    return this.$resourceLifecycleConfig;
                }

                @Override
                public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$resourceLifecycleConfig = value;
                }

                @Override
                public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value) {
                    this.$resourceLifecycleConfig = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getApplicationName() {
            return this.jsiiGet("applicationName", java.lang.Object.class);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
         */
        @Override
        public void setApplicationName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("applicationName", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
         */
        @Override
        public void setApplicationName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("applicationName", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
         */
        @Override
        public void setDescription(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("description", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
         */
        @Override
        public void setDescription(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("description", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getResourceLifecycleConfig() {
            return this.jsiiGet("resourceLifecycleConfig", java.lang.Object.class);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
         */
        @Override
        public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("resourceLifecycleConfig", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
         */
        @Override
        public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value) {
            this.jsiiSet("resourceLifecycleConfig", value);
        }
    }
}

==> elasticbeanstalk-0.12.0-sources.jar: software/amazon/awscdk/services/elasticbeanstalk/cloudformation/ApplicationResourceProps.java <==
package software.amazon.awscdk.services.elasticbeanstalk.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-12T09:50:20.427Z")
public interface ApplicationResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::ElasticBeanstalk::Application.ApplicationName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
     */
    java.lang.Object getApplicationName();
    /**
     * ``AWS::ElasticBeanstalk::Application.ApplicationName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
     */
    void setApplicationName(final java.lang.String value);
    /**
     * ``AWS::ElasticBeanstalk::Application.ApplicationName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
     */
    void setApplicationName(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::ElasticBeanstalk::Application.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::ElasticBeanstalk::Application.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::ElasticBeanstalk::Application.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
     */
    void setDescription(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
     */
    java.lang.Object getResourceLifecycleConfig();
    /**
     * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
     */
    void setResourceLifecycleConfig(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
     */
    void setResourceLifecycleConfig(final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value);

    /**
     * @return a {@link Builder} of {@link ApplicationResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ApplicationResourceProps}
     */
    final class Builder {
        @javax.annotation.Nullable
        private java.lang.Object _applicationName;
        @javax.annotation.Nullable
        private java.lang.Object _description;
        @javax.annotation.Nullable
        private java.lang.Object _resourceLifecycleConfig;

        /**
         * Sets the value of ApplicationName
         * @param value ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @return {@code this}
         */
        public Builder withApplicationName(@javax.annotation.Nullable final java.lang.String value) {
            this._applicationName = value;
            return this;
        }
        /**
         * Sets the value of ApplicationName
         * @param value ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @return {@code this}
         */
        public Builder withApplicationName(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._applicationName = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::ElasticBeanstalk::Application.Description``
         * @return {@code this}
         */
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::ElasticBeanstalk::Application.Description``
         * @return {@code this}
         */
        public Builder withDescription(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of ResourceLifecycleConfig
         * @param value ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @return {@code this}
         */
        public Builder withResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._resourceLifecycleConfig = value;
            return this;
        }
        /**
         * Sets the value of ResourceLifecycleConfig
         * @param value ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @return {@code this}
         */
        public Builder withResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value) {
            this._resourceLifecycleConfig = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApplicationResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ApplicationResourceProps build() {
            return new ApplicationResourceProps() {
                @javax.annotation.Nullable
                private java.lang.Object $applicationName = _applicationName;
                @javax.annotation.Nullable
                private java.lang.Object $description = _description;
                @javax.annotation.Nullable
                private java.lang.Object $resourceLifecycleConfig = _resourceLifecycleConfig;

                @Override
                public java.lang.Object getApplicationName() {
                    return this.$applicationName;
                }

                @Override
                public void setApplicationName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$applicationName = value;
                }

                @Override
                public void setApplicationName(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$applicationName = value;
                }

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(@javax.annotation.Nullable final java.lang.String value) {
                    this.$description = value;
                }

                @Override
                public void setDescription(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$description = value;
                }

                @Override
                public java.lang.Object getResourceLifecycleConfig() {
                    return this.$resourceLifecycleConfig;
                }

                @Override
                public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$resourceLifecycleConfig = value;
                }

                @Override
                public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value) {
                    this.$resourceLifecycleConfig = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getApplicationName() {
            return this.jsiiGet("applicationName", java.lang.Object.class);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
         */
        @Override
        public void setApplicationName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("applicationName", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ApplicationName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-name
         */
        @Override
        public void setApplicationName(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("applicationName", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
         */
        @Override
        public void setDescription(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("description", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-description
         */
        @Override
        public void setDescription(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("description", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getResourceLifecycleConfig() {
            return this.jsiiGet("resourceLifecycleConfig", java.lang.Object.class);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
         */
        @Override
        public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("resourceLifecycleConfig", value);
        }

        /**
         * ``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-beanstalk.html#cfn-elasticbeanstalk-application-resourcelifecycleconfig
         */
        @Override
        public void setResourceLifecycleConfig(@javax.annotation.Nullable final software.amazon.awscdk.services.elasticbeanstalk.cloudformation.ApplicationResource.ApplicationResourceLifecycleConfigProperty value) {
            this.jsiiSet("resourceLifecycleConfig", value);
        }
    }
}
